@@ -3,11 +3,12 @@ package HTTP::Headers::Auth;
 use strict;
 use warnings;
 
-our $VERSION = "6.07";
+our $VERSION = "6.08";
 
 use HTTP::Headers;
 
-package HTTP::Headers;
+package
+    HTTP::Headers;
 
 BEGIN {
     # we provide a new (and better) implementations below
