@@ -3,12 +3,13 @@ package HTTP::Headers::ETag;
 use strict;
 use warnings;
 
-our $VERSION = "6.07";
+our $VERSION = "6.08";
 
 require HTTP::Date;
 
 require HTTP::Headers;
-package HTTP::Headers;
+package
+    HTTP::Headers;
 
 sub _etags
 {
