@@ -13,7 +13,7 @@ our @EXPORT_OK = qw($DYNAMIC_FILE_UPLOAD DELETE);
 require HTTP::Request;
 use Carp();
 
-our $VERSION = "6.07";
+our $VERSION = "6.08";
 
 my $CRLF = "\015\012";   # "\r\n" is not portable
 
@@ -135,10 +135,10 @@ sub form_data   # RFC1867
     my @data = ref($data) eq "HASH" ? %$data : @$data;  # copy
     my $fhparts;
     my @parts;
-    my($k,$v);
-    while (($k,$v) = splice(@data, 0, 2)) {
+    while (my ($k,$v) = splice(@data, 0, 2)) {
 	if (!ref($v)) {
 	    $k =~ s/([\\\"])/\\$1/g;  # escape quotes and backslashes
+            no warnings 'uninitialized';
 	    push(@parts,
 		 qq(Content-Disposition: form-data; name="$k"$CRLF$CRLF$v));
 	}
